InventoryItem class

Implementers

Constructors

InventoryItem({required String id, required String? title, required String category, required String? metadataId, required String? folderPath, required List<InventoryItemVersion>? versions, required List<InventoryItemAddon>? addons, String? displayImageBlurHash})
InventoryItem.fromJson(Map<String, dynamic> json)
factory

Properties

addons List<InventoryItemAddon>?
final
category String
final
displayImageBlurHash String?
final
folderPath String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadataId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
versions List<InventoryItemVersion>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited